Module ops

Modules

adjust
map

Traits

Adjust
Decrement
Decrement is a trait describing the ability to decrement a value.
Increment
Map
Map is a trait that allows for mapping over a reference to a type T by applying a function F to it, producing a new type U. The result is wrapped in a container type defined by the implementor of the trait.
MapInplace
MapOnce
A the MapOnce trait is similar to Map, but it consumes the instance instead of borrowing it;