Skip to main contentModule string
Source - RemoveFnl
- This trait defines a method for removing the first and last entries within an entity.
- StringFmt
StringFmt is a trait that provides methods for formatting strings.
Note This crate requires the alloc feature