pub trait IncrementMut {
type Output;
// Required method
fn inc_mut(&mut self) -> Self::Output;
}Expand description
IncrementMut is similar to Increment, but it allows for incrementing a value in place.
note: the automatic implementation of IncrementMut leverages the replace
method to compute the next value, replacing and returning the previous value.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".