pub trait RawContainer {
type Item;
}Expand description
RawContainer defines a standard interface for all containers that are used to store
other entities.
pub trait RawContainer {
type Item;
}RawContainer defines a standard interface for all containers that are used to store
other entities.