RemoveFnl

Trait RemoveFnl 

pub trait RemoveFnl {
    type Output;

    // Required method
    fn remove_fnl(&self) -> Self::Output;
}
This trait defines a method for removing the first and last entries within an entity.

Typically, this is used to remove the first and last characters of a string, such as a quote or a parenthesis.

Required Associated Types

Required Methods

fn remove_fnl(&self) -> Self::Output

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl RemoveFnl for String

Available on crate feature alloc only.
Source

impl<'a> RemoveFnl for &'a str

Source

type Output = &'a str

Source

fn remove_fnl(&self) -> Self::Output

Implementors