TypeOf

Trait TypeOf 

pub trait TypeOf {
    // Required method
    fn of<T: 'static>() -> bool;
}
The TypeOf trait automatically provides a way to check if a type is of a specific type at compile time. This is useful for generic programming and type checking.

Required Methods

fn of<T: 'static>() -> bool

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> TypeOf for T
where T: 'static,