Traits
- Into
Inner - IntoInner is typically used for basic structures that wrap a single value.
- RawWrapper
- A
RawWrapperis the base trait defining all so-called “wrapper” types. - Wrapper
- The
Wrappertrait is used to establish a common interface for all simplemented structures that “wrap” a single value. Essentially, any type capable of implementing#[repr(transparent)]can be considered a wrapper.