Traits
- AsSlice
AsSliceis a generic trait for converting a type into a slice of its elements. This is useful for types that can be represented as a contiguous sequence of elements, such as arrays, vectors, or other collections.- AsSlice
Mut AsSliceMutis a generic trait for converting a type into a mutable slice of its elements.