Modules
Traits
- Adjust
- Decrement
Decrementis a trait describing the ability to decrement a value.- Increment
- Map
Mapis a trait that allows for mapping over a reference to a typeTby applying a functionFto it, producing a new typeU. The result is wrapped in a container type defined by the implementor of the trait.- MapInplace
- MapOnce
- A the
MapOncetrait is similar toMap, but it consumes the instance instead of borrowing it;