pub trait RemoveFnl {
type Output;
// Required method
fn remove_fnl(&self) -> Self::Output;
}Expand description
This trait defines a method for removing the first and last entries within an entity.
Typically, this is used to remove the first and last characters of a string, such as a quote or a parenthesis.
Required Associated Types
Required Methods
fn remove_fnl(&self) -> Self::Output
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".