scsys_
traits
0.2.6
Module wrapper
Module Items
Traits
In crate scsys_
traits
scsys_traits
Module
wrapper
Traits

Into
Inner
IntoInner
is typically used for basic structures that wrap a single value.
Mapper
RawWrapper
A
RawWrapper
is the base trait defining all so-called “wrapper” types.
Wrapper
The
Wrapper
trait is used to establish a common interface for all simplemented structures that “wrap” a single value. Essentially, any type capable of implementing
#[repr(transparent)]
can be considered a wrapper.
Wrapper
Ext
WrapperExt
is an automatically implemented trait extending the
Wrapper
trait with additional